@@ -172,12 +172,12 @@ extern unsigned short htons();		/* A macro if NET_ORDER, */
  *		-2:   if the connection failed, and we should retry
  *			after some seconds or minutes.
  */
-int establish (packettype, targetmid, cuid, cusername, transactcc)
-int packettype;
-Mid_t targetmid;
-uid_t cuid;
-char *cusername;
-long *transactcc;
+int establish (
+	int packettype,
+	Mid_t targetmid,
+	uid_t cuid,
+	char *cusername,
+	long *transactcc)
 {
 	
 #if	BSD43 | ULTRIX
