@@ -562,7 +562,7 @@ int interscan (char packet[MAX_PACKET])
 		write_i = 0;
 		while (i < count) {
 			if ((index = i32vread (&ulen, &signbit, packet, index,
-					       packet_size)) == -2 || signbit){
+					       packet_size)) == (unsigned) -2 || signbit){
 				/*
 				 *  The packet is corrupt.
 				 */
@@ -604,7 +604,7 @@ int interscan (char packet[MAX_PACKET])
 		mask = 1;
 		while (i < count) {
 			if ((index = i32vread (&u32s [i++], &signbit, packet,
-					       index, packet_size)) == -2) {
+					       index, packet_size)) == (unsigned) -2) {
 				/*
 				 *  The packet is corrupt.
 				 */
