@@ -175,10 +175,10 @@ static short t_units;			/* scanned units type (QLM_???) */
  *		and a warning quota limit.
  *
  */
-int scanquolim (quolimstr, quolimp, maxonly)
-char *quolimstr;			/* what is to be parsed */
-struct quotalimit *quolimp;		/* where to put the result */
-short maxonly;				/* if non-zero, warn limit illegal */
+int scanquolim (
+	char *quolimstr,		/* what is to be parsed */
+	struct quotalimit *quolimp,	/* where to put the result */
+	short maxonly)			/* if non-zero, warn limit illegal */
 {
 	int trouble;			/* return value of scan1quolim() */
 	unsigned long myulong;		/* dummy arg; never looked at */
@@ -302,9 +302,7 @@ short maxonly;				/* if non-zero, warn limit illegal */
  *	than having scan() do it. This means that "1.2"
  *	can be three tokens, instead of having to be one token.
  */
-static int scan1quolim (ulongp, shortp)
-unsigned long *ulongp;
-short *shortp;
+static int scan1quolim (unsigned long *ulongp, short *shortp)
 {
 	
 	t_int32 = 0;			/* set defaults */
@@ -557,9 +555,7 @@ short *shortp;
  *
  *	Returns: T_<tokentype>.
  */
-static int scanquolim_scan (asfracpart)
-short asfracpart;			/* Non-zero if the following digits */
-					/* are the fractional part */
+static int scanquolim_scan (short asfracpart)
 {
 	register int ch;		/* scan character */
 	register unsigned long i32value;/* integer part being computed */
