@@ -113,9 +113,7 @@ static void adsuid_problem (/* int opcode, char *quename, char *user_name */);
  *	destinations to add/delete/set is defined by the scan_destset()
  *	function which is used to parse a destination set specification.
  */
-void adsdes_set (quename, opcode)
-char *quename;				/* Corresponding queue name */
-int opcode;				/* Operation code = ADD_OP, */
+void adsdes_set (char *quename, int opcode)
 {					/* DEL_OP, or SET_OP. */
 
 	long comcode;			/* Completion code */
@@ -215,10 +213,7 @@ int opcode;				/* Operation code = ADD_OP, */
  *	void adsdes_problem():
  *	Indicate problem adding/deleting/setting queue destination.
  */
-static void adsdes_problem (opcode, quename, destname)
-int opcode;			/* Opcode = ADD_OP, DEL_OP, SET_OP */
-char *quename;			/* Queue name */
-char *destname;			/* Destination */
+static void adsdes_problem (int opcode, char * quename, char * destname)
 {
 	show_failed_prefix();
 	switch (opcode) {
@@ -250,10 +245,8 @@ char *destname;			/* Destination */
  *	of devices to add/delete/set is defined by the scan_devset()
  *	function which is used to parse a device set specification.
  */
-void adsdev_set (quename, opcode)
-char *quename;				/* Corresponding queue name */
-int opcode;				/* Operation code = ADD_OP, */
-{					/* DEL_OP, or SET_OP. */
+void adsdev_set (char *quename, int opcode)
+{				
 
 	long comcode;			/* Completion code */
 	register char *devname;		/* Device name */
@@ -337,10 +330,7 @@ int opcode;				/* Operation code = ADD_OP, */
  *	void adsdev_problem():
  *	Indicate problem adding/deleting/setting queue/device mapping.
  */
-static void adsdev_problem (opcode, quename, devname)
-int opcode;			/* Opcode = ADD_OP, DEL_OP, SET_OP */
-char *quename;			/* Queue name */
-char *devname;			/* Device name */
+static void adsdev_problem (int opcode, char *quename, char *devname)
 {
 	show_failed_prefix();
 	switch (opcode) {
@@ -372,9 +362,8 @@ char *devname;			/* Device name */
  *	is defined by the scan_forset() function which is used to
  *	scan/parse a forms set specification.
  */
-void adsfor_set (opcode)
-int opcode;				/* Operation code = ADD_OP, */
-{					/* DEL_OP, or SET_OP. */
+void adsfor_set (int opcode)
+{
 
 	long comcode;			/* Completion code */
 	register char *formname;	/* Form name */
@@ -444,9 +433,7 @@ int opcode;				/* Operation code = ADD_OP, */
  *	void adsfor_problem():
  *	Indicate problem adding/deleting/setting forms set.
  */
-static void adsfor_problem (opcode, formname)
-int opcode;			/* Opcode = ADD_OP, DEL_OP, SET_OP */
-char *formname;			/* Forms name */
+static void adsfor_problem (int opcode, char *formname)
 {
 	show_failed_prefix();
 	switch (opcode) {
@@ -475,9 +462,7 @@ char *formname;			/* Forms name */
  *	which is used to scan/parse a gid set specification.
  *	Setting is currently impossible.
  */
-void adsgid_set (quename, opcode)
-char *quename;				/* Queue name */
-int opcode;				/* Operation code = ADD_OP or DEL_OP */
+void adsgid_set (char *quename, int opcode)
 {
 	long comcode;			/* Completion code */
 	register short exitflag;	/* Exit flag */
@@ -548,10 +533,7 @@ int opcode;				/* Operation code = ADD_OP or DEL_OP */
  *	void adsgid_problem():
  *	Indicate problem adding/deleting/setting gid set.
  */
-static void adsgid_problem (opcode, quename, group_name)
-int opcode;			/* Opcode = ADD_OP or DEL_OP*/
-char *quename;				/* Queue name */
-char *group_name;			/* Group as specified by qmgr user */
+static void adsgid_problem (int opcode, char *quename, char *group_name)
 {
 	show_failed_prefix();
 	switch (opcode) {
@@ -576,9 +558,8 @@ char *group_name;			/* Group as specified by qmgr user */
  *	add/delete/set is defined by the scan_mgrset() function which
  *	is used to scan/parse a manager account set specification.
  */
-void adsmgr_set (opcode)
-int opcode;				/* Operation code = ADD_OP, */
-{					/* DEL_OP, or SET_OP. */
+void adsmgr_set (int opcode)
+{
 
 	long comcode;			/* Completion code */
 	register short exitflag;	/* Exit flag */
@@ -660,9 +641,7 @@ int opcode;				/* Operation code = ADD_OP, */
  *	void adsmgr_problem():
  *	Indicate problem adding/deleting/setting manager set.
  */
-static void adsmgr_problem (opcode, mgr_name)
-int opcode;			/* Opcode = ADD_OP, DEL_OP, SET_OP */
-char *mgr_name;			/* Manager account name */
+static void adsmgr_problem (int opcode, char *mgr_name)
 {
 	show_failed_prefix();
 	switch (opcode) {
@@ -757,10 +736,10 @@ int opcode;                             /* Operation code = ADD_OP or DEL_OP */{
  *      void adsque_problem():
  *      Indicate problem adding/removing/setting queue set.
  */
-static void adsque_problem (opcode, que_name, qcom_name)
-int opcode;                             /* Opcode = ADD_OP or DEL_OP */
-char *que_name;                         /* Queue name */
-char *qcom_name;                        /* Queue complex name */
+static void adsque_problem (
+	int opcode,                     /* Opcode = ADD_OP or DEL_OP */
+	char *que_name,                 /* Queue name */
+	char *qcom_name)                /* Queue complex name */
 {
         show_failed_prefix();
         switch (opcode) {
@@ -785,9 +764,7 @@ char *qcom_name;                        /* Queue complex name */
  *	which is used to scan/parse a uid set specification.
  *	Setting is currently impossible.
  */
-void adsuid_set (quename, opcode)
-char *quename;				/* Queue name */
-int opcode;				/* Operation code = ADD_OP or DEL_OP */
+void adsuid_set (char *quename, int opcode)
 {
 
 	long comcode;			/* Completion code */
@@ -859,10 +836,10 @@ int opcode;				/* Operation code = ADD_OP or DEL_OP */
  *	void adsuid_problem():
  *	Indicate problem adding/deleting/setting uid set.
  */
-static void adsuid_problem (opcode, quename, user_name)
-int opcode;				/* Opcode = ADD_OP or DEL_OP */
-char *quename;				/* Queue name */
-char *user_name;			/* Account name */
+static void adsuid_problem (
+	int opcode,		/* Opcode = ADD_OP or DEL_OP */
+	char *quename,		/* Queue name */
+	char *user_name)	/* Account name */
 {
 	show_failed_prefix();
 	switch (opcode) {
