@@ -267,10 +267,7 @@ int DEBUG;				/* Debug flag for interactive pgms */
  *	number [0..31] (see ../lib/transact.c).
  *
  */
-main (argc, argv, envp)
-int argc;
-char *argv [];
-char *envp [];
+main (int argc, char *argv[], char *envp[])
 {
 
 	struct rawreq rawreq;	/* To hold the control file header */
@@ -368,10 +365,10 @@ char *envp [];
  *	the one-two punch of pipe queues and network queues.
  *	This routine empties network queues.
  */
-static long do_delivery (rawreq, cuid, cusername)
-struct rawreq *rawreq;
-uid_t cuid;
-char *cusername;
+static long do_delivery (
+	struct rawreq *rawreq,
+	uid_t cuid,
+	char *cusername)
 {
 	return (mergertcm (RCM_DELIVERFAI, TCML_FATALABORT));
 }
@@ -386,10 +383,10 @@ char *cusername;
  *	from the output spooling area to a reasonable final location,
  *	possibly on another machine.
  */
-static long do_stageout (rawreq, cuid, cusername)
-struct rawreq *rawreq;
-uid_t cuid;
-char *cusername;
+static long do_stageout (
+	struct rawreq *rawreq,
+	uid_t cuid,
+	char *cusername)
 {
 
 	char *asciievent;		/* Ascii val of env var */
@@ -430,9 +427,9 @@ char *cusername;
  *	Returns: RCM_STAGEOUT (might have information bits)
  *		 RCM_STAGEOUTFAI (will have information bits)
  */
-static long do_stdout (rawreq, passwd)
-struct rawreq *rawreq;
-struct passwd *passwd;
+static long do_stdout (
+	struct rawreq *rawreq,
+	struct passwd *passwd)
 {
 	char *cp;				/* Character pointer */
 	char *tempname;				/* Spooled file pathname */
@@ -611,9 +608,9 @@ of %s for stdout, errno = %d\n", last_chance_path, errno);
  *		 RCM_STAGEOUTFAI (will have information bits)
  *
  */
-static long do_stderr (rawreq, passwd)
-struct rawreq *rawreq;
-struct passwd *passwd;
+static long do_stderr (
+	struct rawreq *rawreq,
+	struct passwd *passwd)
 {
 	
 	char *cp;				/* Character pointer */
@@ -798,9 +795,7 @@ of %s for stderr, errno = %d\n", last_chance_path, errno);
  *		(never mentioning why return to the primary location failed)
  *
  */
-static long rightrcm (remotercm, localrcm)
-long remotercm;
-long localrcm;
+static long rightrcm (long remotercm, long localrcm)
 {
 	if ((localrcm & XCI_REASON_MASK) == RCM_STAGEOUT) {
 		return (RCM_STAGEOUTBAK | (remotercm & XCI_INFORM_MASK));
@@ -817,12 +812,12 @@ long localrcm;
  *	If successful, return RCM_STAGEOUT and unlink tempname.
  *	If unsuccessful, return RCM_STAGEOUTFAI and do not unlink.
  */
-static long trythere (tempname, dest, dest_mid, statbuf, passwd)
-char *tempname;				/* Where we spooled it */
-char *dest;				/* Path on remote machine */
-Mid_t dest_mid;				/* Nmap mid for remote machine */
-struct stat *statbuf;			/* Stat of spooled copy */
-struct passwd *passwd;			/* Password on our machine */
+static long trythere (
+	char *tempname,			/* Where we spooled it */
+	char *dest,			/* Path on remote machine */
+	Mid_t dest_mid,			/* Nmap mid for remote machine */
+	struct stat *statbuf,		/* Stat of spooled copy */
+	struct passwd *passwd)		/* Password on our machine */
 {
 	
 	int fd;
@@ -961,11 +956,11 @@ struct passwd *passwd;			/* Password on our machine */
  *	If successful, return RCM_STAGEOUT and unlink tempname.
  *	If unsuccessful, return RCM_STAGEOUTFAI and do not unlink.
  */
-static long tryhere (temp, dest, statbuf, mode)
-char *temp;				/* Temporary name */
-char *dest;				/* Destination name */
-struct stat *statbuf;			/* Result of stat() on temp */
-int mode;				/* Destination file mode */
+static long tryhere (
+	char *temp,			/* Temporary name */
+	char *dest,			/* Destination name */
+	struct stat *statbuf,		/* Result of stat() on temp */
+	int mode)			/* Destination file mode */
 {
 
 	short waitmsg;			/* Wait message flag */
@@ -1022,10 +1017,10 @@ int mode;				/* Destination file mode */
  *		0: if successful.
  *	       -1: if unsuccessful.
  */
-static int copy (temp, dest, mode)
-char *temp;				/* Name of temporary file */
-char *dest;				/* Name of destination file */
-int mode;				/* File creation mode */
+static int copy (
+	char *temp,		/* Name of temporary file */
+	char *dest,		/* Name of destination file */
+	int mode)		/* File creation mode */
 {
 
 	register int srcfd;
@@ -1062,11 +1057,11 @@ int mode;				/* File creation mode */
  *	Behave just as the open(2) system call does, only
  *	try to turn failure into success.
  */
-static int robustopen (path, flags, mode)
-char *path;					/* Path name */
-int flags;					/* O_??? */
-int mode;					/* Rwx permissions, not */
-						/* used if we only read */
+static int robustopen (
+	char *path,		/* Path name */
+	int flags,		/* O_??? */
+	int mode)		/* Rwx permissions, not */
+				/* used if we only read */
 {
 	
 	short descr_wait;			/* Boolean */
