@@ -169,6 +169,11 @@ long nqs_quereq (
 			  (int) (orig_seqno % MAX_CTRLSUBDIRS), (char *) 0,
 			  (long) orig_seqno, 5, (long) orig_mid, 6, 0, 0);
 	}
+	if (Debug)
+	{
+		printf("D$Attempting to open file %s\n", newpath);
+		fflush(stdout);
+	}
 	if ((cfd = open (newpath, O_RDWR)) == -1) {
 		/*
 		 *  We are unable to open the control file!
