@@ -1,3 +1,8 @@
+From ae006ei@indy3e.rz.rwth-aachen.de Mon Jul 10 13:59:52 1995
+Date: Tue, 13 Jun 1995 15:38:16 +0200
+From: "Herr Th. Eifert" <ae006ei@indy3e.rz.rwth-aachen.de>
+To: s.herbert@sheffield.ac.uk
+
 /*
  *	Network Queueing System (NQS)
  *  This version of NQS is Copyright (C) 1992  John Roman
@@ -859,7 +864,7 @@ void print_termination (struct acct_record *arp)
 	fmtmidname(arp->orig_mid));
     printf(" %-9.9s",  arp->queue);
 #if     HPUX | SGI | SOLARIS | SYS52 | IBMRS | LINUX
-#if	IBMRS
+#if	IBMRS | SGI
     cpu_time = (double) (arp->tms_stime+arp->tms_utime);
     printf(" %9.2f",  cpu_time/100.0);
 #else
@@ -903,7 +908,7 @@ void print_summary (struct nqsacct_summ *arp)
     printf("%6d.%-8.8s", arp->seqno,  
 	fmtmidname(arp->orig_mid));
     printf(" %-9.9s",  arp->queue);
-#if	IBMRS
+#if	IBMRS | SGI
     cpu_time = (double) (arp->s_time+arp->u_time);
     printf(" %9.2f",  cpu_time/100.0);
 #else
@@ -1077,7 +1082,7 @@ void add_sum_to_summary (struct nqsacct_summ *arp)
 			!strcmp(userq_p->user, arp->user) ){
 	    userq_p->count += 1;
 	    record_cputime = (double) (arp->s_time+arp->u_time);
-#if	IBMRS
+#if	IBMRS | SGI
 	    record_cputime /= 100.0;
 #endif
 	    userq_p->cputime += record_cputime;
@@ -1098,7 +1103,7 @@ void add_sum_to_summary (struct nqsacct_summ *arp)
     userq_p2->count += 1;
 	
     record_cputime = (double) (arp->s_time+arp->u_time);
-#if	IBMRS
+#if	IBMRS | SGI
     record_cputime /= 100.0;
 #endif
     userq_p2->cputime = record_cputime;
@@ -1128,7 +1133,7 @@ void add_term_to_summary(struct acct_record  *arp)
 BAD SYSTEM TYPE
 #endif
 #endif
-#if	IBMRS
+#if	IBMRS | SGI
 	    record_cputime /= 100.0;
 #endif
 	    userq_p->cputime += record_cputime;
@@ -1157,7 +1162,7 @@ BAD SYSTEM TYPE
 BAD SYSTEM TYPE
 #endif
 #endif
-#if	IBMRS
+#if	IBMRS | SGI
     record_cputime /= 100.0;
 #endif
     userq_p2->cputime = record_cputime;
@@ -1233,7 +1238,7 @@ void produce_summary_report()
 	q_p2++;
 	q_p = q_p->next;
     }
-    qsort (q_array,  q_count,  sizeof (struct qstruct), (void *)q_sortrtn);
+    qsort (q_array,  q_count,  sizeof (struct qstruct), q_sortrtn);
     userq_array = (struct userqstruct *) malloc (userq_count * sizeof (struct userqstruct) );
     if (userq_array == (struct userqstruct *) NULL) {
 	fprintf(stderr,  "Error getting space for userq_array.\n");
@@ -1248,7 +1253,7 @@ void produce_summary_report()
 	userq_p = userq_p->next;
     }
     qsort (userq_array,  userq_count,  sizeof (struct userqstruct), 
-				(void *)userq_sortrtn);
+				userq_sortrtn);
     printf ("\n%9s", "");
     q_p = q_array;
     for (i = 0; i < q_count; i++ ){
@@ -1348,3 +1353,4 @@ fprintf (stderr, " -u username     selects only records of that user\n");
 fprintf (stderr, " -v              prints version information\n");
 exit (0);
 }
+
